**What has each group member done since the submission of Milestone 1:**

We currently have not started implementing the AD package yet. Our plan for splitting up work is listed as the answer to the prompt below. We worked together to respond to the feedback from Milestone 1 and submitted that for Milestone 2A (this was clarified in an email chain with our TF Wenqi).

**What tasks has each group member been assigned to for Milestone 2.**

Nithin: 

- Test suite
- Proposal for future features
- Documentation (example use cases)

Chris:

- Part of forward mode AD implementation (operator overloading)
- Documentation (function & class documentation)

Andrew: 

- Part of forward mode AD implementation (dual numbers and variables)
- Documentation (function & class documentation)

Yingzhi: 

- Packaging files (and upload to test index)
- CI integration
- Test suite
- Documentation (how to install, etc.)


**Next, we provide an approximate timeline for the completion of all features in the AD package.**

11/10 - 11/12: Chris and Andrew will implement forward mode AD. Nithin will write the proposal for future features. Yingzhi will write the packaging files and write a skeleton for our eventual CI integration.

11/13 - 11/15: Chris and Andrew write documentation for the classes and function created in AD implementation. Nithin and Yingzhi write the test suite for forward mode AD.

11/16 - 11/17: Nithin writes use cases for the AD documentation. Chris and Andrew finish the documentation for forward mode AD functions and classes. Yingzhi writes the installation documentation and finishes the CI workflows.

